@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Nette Framework (http://nette.org)
- * Copyright (c) 2004 David Grudl (http://davidgrudl.com)
+ * This file is part of the Nette Framework (https://nette.org)
+ * Copyright (c) 2004 David Grudl (https://davidgrudl.com)
  */
 
 namespace Nette\DI;
@@ -183,7 +183,7 @@ class ContainerBuilder extends Nette\Object
 	/**
 	 * Resolves service name by type.
 	 * @param  string  class or interface
-	 * @return string  service name or NULL
+	 * @return string|NULL  service name or NULL
 	 * @throws ServiceCreationException
 	 */
 	public function getByType($class)
@@ -191,13 +191,13 @@ class ContainerBuilder extends Nette\Object
 		$class = ltrim($class, '\\');
 
 		if ($this->currentService !== NULL) {
-			$rc = new ReflectionClass($this->definitions[$this->currentService]->getClass());
-			if ($class === $rc->getName() || $rc->isSubclassOf($class)) {
+			$curClass = $this->definitions[$this->currentService]->getClass();
+			if ($curClass === $class || is_subclass_of($curClass, $class)) {
 				return $this->currentService;
 			}
 		}
 
-		if (!isset($this->classes[$class][TRUE])) {
+		if (empty($this->classes[$class][TRUE])) {
 			self::checkCase($class);
 			return;
 
@@ -220,11 +220,9 @@ class ContainerBuilder extends Nette\Object
 		$class = ltrim($class, '\\');
 		self::checkCase($class);
 		$found = array();
-		foreach (array(TRUE, FALSE) as $mode) {
-			if (!empty($this->classes[$class][$mode])) {
-				foreach ($this->classes[$class][$mode] as $name) {
-					$found[$name] = $this->definitions[$name];
-				}
+		if (!empty($this->classes[$class])) {
+			foreach (call_user_func_array('array_merge', $this->classes[$class]) as $name) {
+				$found[$name] = $this->definitions[$name];
 			}
 		}
 		return $found;
@@ -349,21 +347,21 @@ class ContainerBuilder extends Nette\Object
 		}
 		self::checkCase($interface);
 		$rc = new ReflectionClass($interface);
-		$method = $rc->hasMethod('create') ? $rc->getMethod('create') : ($rc->hasMethod('get') ? $rc->getMethod('get') : NULL);
+		$method = $rc->hasMethod('create')
+			? $rc->getMethod('create')
+			: ($rc->hasMethod('get') ? $rc->getMethod('get') : NULL);
+
 		if (count($rc->getMethods()) !== 1 || !$method || $method->isStatic()) {
 			throw new ServiceCreationException("Interface $interface used in service '$name' must have just one non-static method create() or get().");
 		}
 		$def->setImplementType($methodName = $rc->hasMethod('create') ? 'create' : 'get');
 
 		if (!$def->getClass() && !$def->getEntity()) {
-			$returnType = PhpReflection::parseAnnotation($method, 'return');
+			$returnType = PhpReflection::getReturnType($method);
 			if (!$returnType) {
 				throw new ServiceCreationException("Method $interface::$methodName() used in service '$name' has no @return annotation.");
-			}
-
-			$returnType = PhpReflection::expandClassName(preg_replace('#[|\s].*#', '', $returnType), $rc);
-			if (!class_exists($returnType)) {
-				throw new ServiceCreationException("Please check a @return annotation of the $interface::$methodName() method used in service '$name'. Class '$returnType' cannot be found.");
+			} elseif (!class_exists($returnType)) {
+				throw new ServiceCreationException("Check a @return annotation of the $interface::$methodName() method used in service '$name', class '$returnType' cannot be found.");
 			}
 			$def->setClass($returnType);
 		}
@@ -393,10 +391,10 @@ class ContainerBuilder extends Nette\Object
 			}
 
 			foreach ($method->getParameters() as $param) {
-				$hint = $param->isArray() ? 'array' : PhpReflection::getPropertyType($param);
+				$hint = PhpReflection::getParameterType($param);
 				if (isset($ctorParams[$param->getName()])) {
 					$arg = $ctorParams[$param->getName()];
-					if ($hint !== ($arg->isArray() ? 'array' : PhpReflection::getPropertyType($arg))) {
+					if ($hint !== PhpReflection::getParameterType($arg)) {
 						throw new ServiceCreationException("Type hint for \${$param->getName()} in $interface::$methodName() doesn't match type hint in $class constructor.");
 					}
 					$def->getFactory()->arguments[$arg->getPosition()] = self::literal('$' . $arg->getName());
@@ -425,7 +423,7 @@ class ContainerBuilder extends Nette\Object
 		if ($class = $def->getClass() ?: $class) {
 			$def->setClass($class);
 			if (!class_exists($class) && !interface_exists($class)) {
-				throw new ServiceCreationException("Class or interface $class used in service '$name' not found.");
+				throw new ServiceCreationException("Type $class used in service '$name' not found or is not class or interface.");
 			}
 			self::checkCase($class);
 
@@ -464,11 +462,7 @@ class ContainerBuilder extends Nette\Object
 				throw new ServiceCreationException(sprintf("Factory '%s' used in service '%s' is not callable.", Nette\Utils\Callback::toString($entity), $name[0]));
 			}
 
-			$class = preg_replace('#[|\s].*#', '', PhpReflection::parseAnnotation($reflection, 'return'));
-			if ($class) {
-				$class = $refClass ? PhpReflection::expandClassName($class, $refClass) : ltrim($class, '\\');
-			}
-			return $class;
+			return PhpReflection::getReturnType($reflection);
 
 		} elseif ($service = $this->getServiceName($entity)) { // alias or factory
 			if (Strings::contains($service, '\\')) { // @\Class
@@ -549,7 +543,7 @@ class ContainerBuilder extends Nette\Object
 		$definitions = $this->definitions;
 		ksort($definitions);
 
-		$meta = $containerClass->addProperty('meta', array())
+		$meta = $containerClass->addProperty('meta')
 			->setVisibility('protected')
 			->setValue(array(Container::TYPES => $this->classes));
 
@@ -646,7 +640,8 @@ class ContainerBuilder extends Nette\Object
 
 		$factoryClass->addMethod($def->getImplementType())
 			->setParameters($this->convertParameters($def->parameters))
-			->setBody(str_replace('$this', '$this->container', $code));
+			->setBody(str_replace('$this', '$this->container', $code))
+			->setReturnType(PHP_VERSION_ID >= 70000 ? $def->getClass() : NULL);
 
 		return "return new {$factoryClass->getName()}(\$this);";
 	}
