@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Latte (http://latte.nette.org)
- * Copyright (c) 2008 David Grudl (http://davidgrudl.com)
+ * This file is part of the Latte (https://latte.nette.org)
+ * Copyright (c) 2008 David Grudl (https://davidgrudl.com)
  */
 
 namespace Latte\Macros;
@@ -24,7 +24,8 @@ class BlockMacrosRuntime extends Latte\Object
 	public static function callBlock(\stdClass $context, $name, array $params)
 	{
 		if (empty($context->blocks[$name])) {
-			throw new RuntimeException("Cannot include undefined block '$name'.");
+			$hint = isset($context->blocks) && ($t = Latte\Helpers::getSuggestion(array_keys($context->blocks), $name)) ? ", did you mean '$t'?" : '.';
+			throw new RuntimeException("Cannot include undefined block '$name'$hint");
 		}
 		$block = reset($context->blocks[$name]);
 		$block($context, $params);
